# -*- coding: utf-8 -*-

"""Top-level package for ninjadog."""

__author__ = """Stephan Fitzpatrick"""
__email__ = 'knowsuchagency@gmail.com'
__version__ = '0.2.0'

from ninjadog.ninjadog import render
from ninjadog.ext.jinja2 import jinja2_renderer
